@@ -10,11 +10,13 @@
 #include "../richtextcomposercontroler.h"
 #include <KActionCollection>
 #include <QAction>
+#include <QStandardPaths>
 #include <QTest>
 
 RichTextComposerActionsTest::RichTextComposerActionsTest(QObject *parent)
     : QObject(parent)
 {
+    QStandardPaths::setTestModeEnabled(true);
 }
 
 RichTextComposerActionsTest::~RichTextComposerActionsTest() = default;
@@ -22,8 +24,8 @@ RichTextComposerActionsTest::~RichTextComposerActionsTest() = default;
 void RichTextComposerActionsTest::shouldHaveDefaultValue()
 {
     KPIMTextEdit::RichTextComposer composer;
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
-    KPIMTextEdit::RichTextComposerActions composerActions(&controler);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
+    KPIMTextEdit::RichTextComposerActions composerActions(&controller);
 
     auto actionCollection = new KActionCollection(&composerActions);
     QVERIFY(actionCollection->actions().isEmpty());
@@ -37,8 +39,8 @@ void RichTextComposerActionsTest::shouldHaveDefaultValue()
 void RichTextComposerActionsTest::shouldHaveActions()
 {
     KPIMTextEdit::RichTextComposer composer;
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
-    KPIMTextEdit::RichTextComposerActions composerActions(&controler);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
+    KPIMTextEdit::RichTextComposerActions composerActions(&controller);
 
     auto actionCollection = new KActionCollection(&composerActions);
     composerActions.createActions(actionCollection);
@@ -75,8 +77,8 @@ void RichTextComposerActionsTest::shouldHaveActions()
 void RichTextComposerActionsTest::shouldChangeEnableState()
 {
     KPIMTextEdit::RichTextComposer composer;
-    KPIMTextEdit::RichTextComposerControler controler(&composer);
-    KPIMTextEdit::RichTextComposerActions composerActions(&controler);
+    KPIMTextEdit::RichTextComposerControler controller(&composer);
+    KPIMTextEdit::RichTextComposerActions composerActions(&controller);
 
     auto actionCollection = new KActionCollection(&composerActions);
     composerActions.createActions(actionCollection);
