@@ -115,7 +115,7 @@ private:
     void reformatList(QTextBlock block);
     void reformatList();
 
-    QTextEdit *textEdit = nullptr;
+    QTextEdit *const textEdit;
 
     int listBottomMargin;
     int listTopMargin;
@@ -123,4 +123,3 @@ private:
 };
 }
 //@endcond
-
